@@ -57,8 +57,8 @@ class HttpClient:
         if verify_ssl:
             self.ssl_context = ssl.create_default_context(cafile=certifi.where())
         else:
-            self.ssl_context = False
-            
+            self.ssl_context = False  # type:ignore
+
         self.headers = {"Authorization": f"Bearer {token}", "Content-Type": "application/json"}
         self.session = None
         self.default_timeout = default_timeout
@@ -70,7 +70,7 @@ class HttpClient:
         self.session = aiohttp.ClientSession(
             headers=self.headers,
             connector=aiohttp.TCPConnector(ssl=False) if not self.verify_ssl else None,
-            trust_env=True
+            trust_env=True,
         )
 
     async def graphql(
@@ -193,8 +193,8 @@ class HttpClient:
             ):
                 with attempt:
                     return await self._request(method=method, url=url, data=data, timeout=timeout)
-        except asyncio.TimeoutError:
-            raise AporiaError("Request timed out")
+        except asyncio.TimeoutError as err:
+            raise AporiaError("Request timed out") from err
 
     async def _request(
         self, method: str, url: str, data: Optional[dict] = None, timeout: Optional[int] = None
@@ -279,7 +279,7 @@ class HttpClient:
                 default=orjson_serialize_default_handler,
             )
         except TypeError as err:
-            raise AporiaError(str(err))
+            raise AporiaError(str(err)) from err
 
     async def close(self):
         """Closes the http session."""
