@@ -1,9 +1,10 @@
 from .model_versions_api import delete_model_version, get_model_versions, ModelVersion
-from .monitor_api import create_monitor, delete_monitor, MonitorType
+from .monitor_api import create_monitor, delete_monitor, MonitorType, run_all_monitors
 
 __all__ = [
     "create_monitor",
     "delete_monitor",
+    "run_all_monitors",
     "MonitorType",
     "ModelVersion",
     "get_model_versions",
