@@ -45,7 +45,7 @@ class Fragment:
         if len(missing_fields) > 0:
             raise AporiaError("Missing required fields {}".format(missing_fields))
 
-        return {"id": self.data["id"]}
+        return {"id": self.data["id"]} if "id" in self.data else {}
 
     @property
     def required_fields(self) -> Set[str]:
@@ -54,7 +54,7 @@ class Fragment:
         Returns:
             Set of required field names.
         """
-        return {"id"}
+        return set()
 
     @property
     def missing_fields(self) -> Set[str]:
@@ -75,7 +75,8 @@ class Fragment:
             logger.warning("Invalid input - Missing required fields {}".format(self.missing_fields))
             return False
 
-        if not isinstance(self.data["id"], str):
+        id = self.data.get("id")
+        if id is not None and not isinstance(id, str):
             logger.warning("Invalid input - id field must be a string.")
             return False
 
