@@ -73,9 +73,9 @@ class InferenceModel(BaseModel):
     @validate_model_ready
     def log_prediction(
         self,
-        id: str,
         features: Union[Dict[str, FieldValue], ndarray],
         predictions: Dict[str, FieldValue],
+        id: Optional[str] = None,
         metrics: Optional[Dict[str, FieldValue]] = None,
         occurred_at: Optional[datetime] = None,
         confidence: Optional[Union[float, List[float]]] = None,
@@ -120,11 +120,11 @@ class InferenceModel(BaseModel):
             batch_predictions: An iterable that produces prediction dicts.
 
                 * Each prediction dict MUST contain the following keys:
-                    * id (str): Prediction identifier.
                     * features (Dict[str, FieldValue]): Values for all the features in the prediction
                     * predictions (Dict[str, FieldValue]): Prediction result
 
                 * Each prediction dict MAY also contain the following keys:
+                    * id (str): Prediction identifier.
                     * occurred_at (datetime): Prediction timestamp.
                     * metrics (Dict[str, FieldValue]): Prediction metrics
                     * confidence (Union[float, List[float]]): Prediction confidence.
