@@ -101,7 +101,7 @@ async def log_training_data(
     model_id: str,
     model_version: str,
     features: List[FieldTrainingData],
-    labels: List[FieldTrainingData],
+    labels: Optional[List[FieldTrainingData]] = None,
     raw_inputs: Optional[List[FieldTrainingData]] = None,
 ):
     """Reports training data.
@@ -119,7 +119,7 @@ async def log_training_data(
             $modelId: String!,
             $modelVersion: String!,
             $features: [FieldTrainingData]!
-            $labels: [FieldTrainingData]!
+            $labels: [FieldTrainingData]
             $rawInputs: [FieldTrainingData]
         ) {
             logTrainingSet(
@@ -138,11 +138,15 @@ async def log_training_data(
     if raw_inputs is not None:
         serialized_raw_inputs = [field_data.serialize() for field_data in raw_inputs]
 
+    serialized_labels = None
+    if labels is not None:
+        serialized_labels = [field_data.serialize() for field_data in labels]
+
     variables = {
         "modelId": model_id,
         "modelVersion": model_version,
         "features": [field_data.serialize() for field_data in features],
-        "labels": [field_data.serialize() for field_data in labels],
+        "labels": serialized_labels,
         "rawInputs": serialized_raw_inputs,
     }
 
@@ -216,7 +220,7 @@ async def log_training_sample_data(
     model_id: str,
     model_version: str,
     features: List[Dict[str, Any]],
-    labels: List[Any],
+    labels: Optional[List[Any]] = None,
     raw_inputs: Optional[List[Any]] = None,
 ):
     """Reports training sample.
