@@ -44,15 +44,13 @@ class TrainingModel(BaseModel):
     def log_training_set(
         self,
         features: Union[DataFrame, ndarray],
-        labels: DataFrame,
+        labels: Optional[DataFrame] = None,
         raw_inputs: Optional[DataFrame] = None,
         sample: bool = True,
     ):
         """See aporia.model.Model."""
         logger.debug("Logging training set.")
-        with self.handle_error(
-            "Logging training set failed, error: {}"
-        ):
+        with self.handle_error("Logging training set failed, error: {}"):
             version_schema = self.get_version_schema()
             validator = TrainingValidator(
                 dataset_type=TrainingDataset.TRAINING, schema=version_schema
@@ -65,6 +63,12 @@ class TrainingModel(BaseModel):
                     raw_inputs, version_schema[FieldCategory.RAW_INPUTS]
                 )
 
+            labels_training_data = None
+            if labels is not None:
+                labels_training_data = calculate_dataframe_training_data(
+                    labels, version_schema[FieldCategory.PREDICTIONS]
+                )
+
             if isinstance(features, DataFrame):
                 features_dataframe = features
                 features_schema = version_schema[FieldCategory.FEATURES]
@@ -81,9 +85,7 @@ class TrainingModel(BaseModel):
             )
             self.log_training_set_aggregations(
                 features=calculate_dataframe_training_data(features_dataframe, features_schema),
-                labels=calculate_dataframe_training_data(
-                    labels, version_schema[FieldCategory.PREDICTIONS]
-                ),
+                labels=labels_training_data,
                 raw_inputs=raw_inputs_training_data,
             )
 
@@ -134,7 +136,7 @@ class TrainingModel(BaseModel):
     def log_training_set_aggregations(
         self,
         features: List[FieldTrainingData],
-        labels: List[FieldTrainingData],
+        labels: Optional[List[FieldTrainingData]] = None,
         raw_inputs: Optional[List[FieldTrainingData]] = None,
     ):
         """Logs training set training aggregations.
@@ -187,7 +189,7 @@ class TrainingModel(BaseModel):
     def log_training_data(
         self,
         features: Union[DataFrame, ndarray],
-        labels: DataFrame,
+        labels: Optional[DataFrame] = None,
         raw_inputs: Optional[DataFrame] = None,
         sample: Optional[bool] = True,
     ):
@@ -211,7 +213,10 @@ class TrainingModel(BaseModel):
         features_sample = cast(
             DataFrame, features.sample(min(report_size, len(features))).fillna(nan)
         )
-        labels_sample = cast(DataFrame, labels.sample(min(report_size, len(labels))).fillna(nan))
+        if labels is not None:
+            labels_sample = cast(
+                DataFrame, labels.sample(min(report_size, len(labels))).fillna(nan)
+            )
 
         if raw_inputs is not None:
             raw_inputs_sample = cast(
@@ -224,12 +229,12 @@ class TrainingModel(BaseModel):
                 model_id=self.model_id,
                 model_version=self.model_version,
                 features=features_sample.to_dict("records"),
-                labels=labels_sample.to_dict("records"),
+                labels=labels_sample.to_dict("records") if labels is not None else None,
                 raw_inputs=raw_inputs_sample.to_dict("records") if raw_inputs is not None else None,
             )
         )
 
-    @lru_cache(maxsize=1)
+    @lru_cache(maxsize=1)  # noqa: B019
     @validate_model_ready
     def get_version_schema(self) -> Dict[FieldCategory, Dict[str, FieldType]]:
         """Fetches the schema of this model version.
